import setuptools
setuptools.setup(
 name='reemweight', 
 version='0.3',
 author="Reem Almoshbb",
 author_email="rsalmoshbb@gmail.com",
 description="<The Python package is designed to assist with the initialization of weights in a neural network sequential model. The package uses machine learning algorithms (MLAs) to initialize the weights, which can lead to improved model performance. Additionally, the package provides a means to compare the results of this weight strategy with other weight initialization strategies.>",
 packages=setuptools.find_packages(),
 classifiers=[
 "Programming Language :: Python :: 3",
 "License :: OSI Approved :: MIT License",
 "Operating System :: OS Independent",
 ],
)
